@@ -9,9 +9,9 @@ RSpec.describe Guard::Guardfile::Evaluator do
   let(:options) { {} }
   subject { described_class.new(options) }
 
-  let!(:local_guardfile) { (Pathname.pwd + "Guardfile").to_s }
-  let!(:home_guardfile) { (Pathname("~").expand_path + ".Guardfile").to_s }
-  let!(:home_config) { (Pathname("~").expand_path + ".guard.rb").to_s }
+  let!(:local_guardfile) { Pathname("Guardfile").to_s }
+  let!(:home_guardfile) { Pathname("~/.Guardfile").expand_path.to_s }
+  let!(:home_config) { Pathname("~/.guard.rb").expand_path.to_s }
 
   let(:valid_guardfile_string) { "group :foo; do guard :bar; end; end; " }
 
@@ -25,6 +25,7 @@ RSpec.describe Guard::Guardfile::Evaluator do
     allow(Guard::Interactor).to receive(:new).with(false)
     allow(Guard::Dsl).to receive(:new).and_return(dsl)
     allow(dsl).to receive(:instance_eval)
+    stub_pathname
   end
 
   describe ".evaluate" do
@@ -45,6 +46,7 @@ RSpec.describe Guard::Guardfile::Evaluator do
 
       context "with no Guardfile at all" do
         it "displays an error message and exits" do
+          stub_guardfile_rb
           stub_guardfile
           stub_user_guardfile
           stub_user_project_guardfile
@@ -54,11 +56,19 @@ RSpec.describe Guard::Guardfile::Evaluator do
         end
       end
 
+      context "with Guardfile as guardfile.rb" do
+        it "evalutates guardfile.rb" do
+          stub_guardfile_rb("guard :bar")
+          allow(dsl).to receive(:evaluate).with("guard :bar", "", 1)
+        end
+      end
+
       context "with a problem reading a Guardfile" do
         let(:path) { File.expand_path("Guardfile") }
 
         before do
           stub_user_project_guardfile
+          stub_guardfile_rb
           stub_guardfile(" ") do
             fail Errno::EACCES.new("permission error")
           end
@@ -88,6 +98,7 @@ RSpec.describe Guard::Guardfile::Evaluator do
           # Anything
           stub_guardfile("guard :foo")
 
+          stub_guardfile_rb
           stub_user_guard_rb
           stub_user_project_guardfile
           stub_user_guardfile
@@ -136,6 +147,7 @@ RSpec.describe Guard::Guardfile::Evaluator do
 
           before do
             stub_file("/abc/Guardfile", "guard :bar")
+            stub_guardfile_rb("guard :baz")
             stub_guardfile("guard :baz")
             stub_user_guardfile("guard :buz")
           end
@@ -164,15 +176,21 @@ RSpec.describe Guard::Guardfile::Evaluator do
     before do
       allow(dsl).to receive(:evaluate)
       stub_guardfile("guard :bar")
+      stub_guardfile_rb
       stub_user_guard_rb
       subject.evaluate
     end
 
-    context "when content is provided" do
+    context "when guardfile_contents is provided" do
       let(:options) { { guardfile_contents: "guard :foo" } }
       it { is_expected.to be_inline }
     end
 
+    context "when contents is provided" do
+      let(:options) { { contents: "guard :foo" } }
+      it { is_expected.to be_inline }
+    end
+
     context "when no content is provided" do
       let(:options) { {} }
       it { is_expected.to_not be_inline }
