@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require "guard/watcher/pattern/match_result"
 
 RSpec.describe Guard::Watcher::Pattern::MatchResult do
@@ -15,7 +17,7 @@ RSpec.describe Guard::Watcher::Pattern::MatchResult do
 
   describe "#[]" do
     context "with a valid match" do
-      let(:match_result) { double("match_data", to_a: %w(foo bar baz)) }
+      let(:match_result) { double("match_data", to_a: %w[foo bar baz]) }
 
       context "when asked for the non-first item" do
         let(:index) { 1 }
